@@ -1,4 +1,5 @@
 #include "common/printing.h"
+#include "logo/logo.h"
 #include "modules/break/break.h"
 
 void ffPrintBreak(FF_MAYBE_UNUSED FFBreakOptions* options)
@@ -16,19 +17,17 @@ void ffParseBreakJsonObject(FF_MAYBE_UNUSED FFBreakOptions* options, FF_MAYBE_UN
 {
 }
 
+static FFModuleBaseInfo ffModuleInfo = {
+    .name = FF_BREAK_MODULE_NAME,
+    .description = "Print a empty line",
+    .parseCommandOptions = (void*) ffParseBreakCommandOptions,
+    .parseJsonObject = (void*) ffParseBreakJsonObject,
+    .printModule = (void*) ffPrintBreak,
+};
+
 void ffInitBreakOptions(FF_MAYBE_UNUSED FFBreakOptions* options)
 {
-    ffOptionInitModuleBaseInfo(
-        &options->moduleInfo,
-        FF_BREAK_MODULE_NAME,
-        "Print a empty line",
-        ffParseBreakCommandOptions,
-        ffParseBreakJsonObject,
-        ffPrintBreak,
-        NULL,
-        NULL,
-        NULL
-    );
+    options->moduleInfo = ffModuleInfo;
 }
 
 void ffDestroyBreakOptions(FF_MAYBE_UNUSED FFBreakOptions* options)
